@@ -1,26 +1,28 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
+from velbus.message import Message
+from velbus.command_registry import register_command
 
 COMMAND_CODE = 0xfe
 
 
-class MemoryDataMessage(velbus.Message):
+class MemoryDataMessage(Message):
     """
     send by: VMB6IN, VMB4RYLD
     received by:
     """
 
-    def __init__(self):
-        velbus.Message.__init__(self)
+    def __init__(self, address=None):
+        Message.__init__(self)
         self.high_address = 0x00
         self.low_address = 0x00
         self.data = bytes([])
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -33,7 +35,7 @@ class MemoryDataMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([
             COMMAND_CODE,
@@ -42,4 +44,4 @@ class MemoryDataMessage(velbus.Message):
         ]) + self.data
 
 
-velbus.register_command(COMMAND_CODE, MemoryDataMessage)
+register_command(COMMAND_CODE, MemoryDataMessage)
