@@ -145,4 +145,6 @@ register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGP4')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGP0')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGPOD')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMB7IN')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMB4DC')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBDME')
 register_command(COMMAND_CODE, ModuleStatusPirMessage, 'VMBIRO')
