@@ -1,19 +1,20 @@
 """
 :author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
+from velbus.message import Message
+from velbus.command_registry import register_command
 
 COMMAND_CODE = 0xfc
 
 
-class WriteDataToMemoryMessage(velbus.Message):
+class WriteDataToMemoryMessage(Message):
     """
     send by:
     received by: VMB6IN, VMB4RYLD
     """
 
     def __init__(self, address=None):
-        velbus.Message.__init__(self)
+        Message.__init__(self)
         self.high_address = 0x00
         self.low_address = 0x00
         self.data = ""
@@ -39,4 +40,4 @@ class WriteDataToMemoryMessage(velbus.Message):
         return bytes([COMMAND_CODE, self.high_address, self.low_address, self.data])
 
 
-velbus.register_command(COMMAND_CODE, WriteDataToMemoryMessage)
+register_command(COMMAND_CODE, WriteDataToMemoryMessage)
